@@ -2,8 +2,7 @@
 
 =head1 NAME
 
-JMX::Jmx4Perl::Response - Encapsulates as JMX Response as it comes from the
-observered Server
+JMX::Jmx4Perl::Response - Encapsulates a jmx4perl response 
 
 =head1 SYNOPSIS
 
@@ -17,8 +16,8 @@ the answer as returned by a L<JMX::Jmx4Perl> backend. Depending on the
 C<status> it either contains the result of a valid request or a error message.
 The status is modelled after HTTP response codes (see
 L<http://www.w3.org/Protocols/rfc2616/rfc2616-sec10.html>). For now, only the
-codes C<200> and C<5xx> codes are used to specified successful request and
-errors respectively.
+codes C<200> and C<400 .. 599> codes are used to specified successful request
+and errors respectively.
 
 =head1 METHODS
 
@@ -57,6 +56,7 @@ sub new {
 Return the status code of this response. Status codes are modelled after HTTP
 return codes. C<200> is the code for a suceeded request. Any code in the range
 500 - 599 specifies an error.
+
 =cut
 
 sub status {
@@ -74,7 +74,7 @@ sub is_ok {
     return shift->{status} == 200;
 }
 
-=item $fault = $resonse_is_error()
+=item $fault = $response->is_error()
 
 Opposite of C<is_ok>, i.e. return true if the status code is B<not> equal to
 200 
@@ -126,7 +126,7 @@ sub request {
     return shift->{request};
 }
 
-=back 
+=back
 
 =head1 LICENSE
 
@@ -145,6 +145,9 @@ GNU General Public License for more details.
 You should have received a copy of the GNU General Public License
 along with jmx4perl.  If not, see <http://www.gnu.org/licenses/>.
 
+A commercial license is available as well. Please contact roland@cpan.org for
+further details.
+
 =head1 AUTHOR
 
 roland@cpan.org
